@@ -1,6 +1,6 @@
 import numpy as np
 import pandas as pd
-from datetime import datetime, timedelta
+from datetime import datetime, timedelta, timezone
 import pytest
 
 import vectorbt as vbt
@@ -80,9 +80,15 @@ class TestData:
             )
         )
         index = pd.DatetimeIndex(
-            ['2020-01-01', '2020-01-02', '2020-01-03', '2020-01-04', '2020-01-05'],
-            dtype='datetime64[ns]',
-            freq='D'
+            [
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00'
+            ],
+            freq='D',
+            tz=timezone.utc
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,)).data[0],
@@ -189,16 +195,16 @@ class TestData:
                 index=index
             )
         )
-        tzaware_index = pd.DatetimeIndex(
+        index2 = pd.DatetimeIndex(
             [
-                '2020-01-01 01:00:00',
-                '2020-01-02 01:00:00',
-                '2020-01-03 01:00:00',
-                '2020-01-04 01:00:00',
-                '2020-01-05 01:00:00'
+                '2020-01-01 02:00:00',
+                '2020-01-02 02:00:00',
+                '2020-01-03 02:00:00',
+                '2020-01-04 02:00:00',
+                '2020-01-05 02:00:00'
             ],
-            dtype='datetime64[ns, Europe/Berlin]',
-            freq='D'
+            freq='D',
+            tz=timezone(timedelta(hours=2))
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,), tz_localize='UTC', tz_convert='Europe/Berlin').data[0],
@@ -210,7 +216,7 @@ class TestData:
                     0.5986584841970366,
                     0.15601864044243652
                 ],
-                index=tzaware_index
+                index=index2
             )
         )
         index_mask = vbt.symbol_dict({
@@ -388,9 +394,15 @@ class TestData:
             )
         )
         index = pd.DatetimeIndex(
-            ['2020-01-01', '2020-01-02', '2020-01-03', '2020-01-04', '2020-01-05'],
-            dtype='datetime64[ns]',
-            freq='D'
+            [
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00'
+            ],
+            freq='D',
+            tz=timezone.utc
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,)).update().data[0],
@@ -405,10 +417,17 @@ class TestData:
                 index=index
             )
         )
-        index2 = pd.DatetimeIndex(
-            ['2020-01-01', '2020-01-02', '2020-01-03', '2020-01-04', '2020-01-05', '2020-01-06'],
-            dtype='datetime64[ns]',
-            freq='D'
+        updated_index = pd.DatetimeIndex(
+            [
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00',
+                '2020-01-06 00:00:00'
+            ],
+            freq='D',
+            tz=timezone.utc
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,)).update(n=2).data[0],
@@ -421,19 +440,19 @@ class TestData:
                     0.11505456638977896,
                     0.6090665392794814
                 ],
-                index=index2
+                index=updated_index
             )
         )
-        tzaware_index = pd.DatetimeIndex(
+        index2 = pd.DatetimeIndex(
             [
-                '2020-01-01 01:00:00',
-                '2020-01-02 01:00:00',
-                '2020-01-03 01:00:00',
-                '2020-01-04 01:00:00',
-                '2020-01-05 01:00:00'
+                '2020-01-01 02:00:00',
+                '2020-01-02 02:00:00',
+                '2020-01-03 02:00:00',
+                '2020-01-04 02:00:00',
+                '2020-01-05 02:00:00'
             ],
-            dtype='datetime64[ns, Europe/Berlin]',
-            freq='D'
+            freq='D',
+            tz=timezone(timedelta(hours=2))
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,), tz_localize='UTC', tz_convert='Europe/Berlin')
@@ -446,7 +465,7 @@ class TestData:
                     0.5986584841970366,
                     0.11505456638977896
                 ],
-                index=tzaware_index
+                index=index2
             )
         )
         index_mask = vbt.symbol_dict({
@@ -501,7 +520,7 @@ class TestData:
                     0.11505456638977896,
                     np.nan
                 ],
-                index=index2
+                index=updated_index
             )
         )
         pd.testing.assert_series_equal(
@@ -516,7 +535,7 @@ class TestData:
                     np.nan,
                     1.6090665392794814
                 ],
-                index=index2
+                index=updated_index
             )
         )
         pd.testing.assert_series_equal(
@@ -614,7 +633,7 @@ class TestData:
                     [np.nan, 0.6090665392794814, 0.13339096418598828],
                     [np.nan, np.nan, np.nan]
                 ],
-                index=index2
+                index=updated_index
             )
         )
         pd.testing.assert_frame_equal(
@@ -630,7 +649,7 @@ class TestData:
                     [np.nan, np.nan, np.nan],
                     [1.2405896199653488, 1.3271390558111398, np.nan]
                 ],
-                index=index2
+                index=updated_index
             )
         )
         pd.testing.assert_frame_equal(
@@ -692,9 +711,15 @@ class TestData:
 
     def test_concat(self):
         index = pd.DatetimeIndex(
-            ['2020-01-01', '2020-01-02', '2020-01-03', '2020-01-04', '2020-01-05'],
-            dtype='datetime64[ns]',
-            freq='D'
+            [
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00'
+            ],
+            freq='D',
+            tz=timezone.utc
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,), columns='feat0').concat()['feat0'],
@@ -811,9 +836,15 @@ class TestData:
 
     def test_get(self):
         index = pd.DatetimeIndex(
-            ['2020-01-01', '2020-01-02', '2020-01-03', '2020-01-04', '2020-01-05'],
-            dtype='datetime64[ns]',
-            freq='D'
+            [
+                '2020-01-01 00:00:00',
+                '2020-01-02 00:00:00',
+                '2020-01-03 00:00:00',
+                '2020-01-04 00:00:00',
+                '2020-01-05 00:00:00'
+            ],
+            freq='D',
+            tz=timezone.utc
         )
         pd.testing.assert_series_equal(
             MyData.download(0, shape=(5,), columns='feat0').get(),
