@@ -11,23 +11,21 @@ seed = 42
 
 day_dt = np.timedelta64(86400000000000)
 
-index = pd.Index([
-    datetime(2020, 1, 1),
-    datetime(2020, 1, 2),
-    datetime(2020, 1, 3),
-    datetime(2020, 1, 4),
-    datetime(2020, 1, 5)
-])
-columns = ['a', 'b', 'c']
 sig = pd.DataFrame([
     [True, False, False],
     [False, True, False],
     [False, False, True],
     [True, False, False],
     [False, True, False]
-], index=index, columns=columns)
+], index=pd.Index([
+    datetime(2020, 1, 1),
+    datetime(2020, 1, 2),
+    datetime(2020, 1, 3),
+    datetime(2020, 1, 4),
+    datetime(2020, 1, 5)
+]), columns=['a', 'b', 'c'])
 
-ts = pd.Series([1., 2., 3., 2., 1.], index=index)
+ts = pd.Series([1., 2., 3., 2., 1.], index=sig.index)
 
 price = pd.DataFrame({
     'open': [10, 11, 12, 11, 10],
@@ -262,6 +260,130 @@ class TestAccessors:
             )
         )
 
+    def test_clean(self):
+        entries = pd.DataFrame([
+            [True, False, True],
+            [True, False, False],
+            [True, True, True],
+            [False, True, False],
+            [False, True, True]
+        ], index=sig.index, columns=sig.columns)
+        exits = pd.Series([True, False, True, False, True], index=sig.index)
+        pd.testing.assert_frame_equal(
+            entries.vbt.signals.clean(),
+            pd.DataFrame(
+                np.array([
+                    [True, False, True],
+                    [False, False, False],
+                    [False, True, True],
+                    [False, False, False],
+                    [False, False, True]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            pd.DataFrame.vbt.signals.clean(entries),
+            pd.DataFrame(
+                np.array([
+                    [True, False, True],
+                    [False, False, False],
+                    [False, True, True],
+                    [False, False, False],
+                    [False, False, True]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            entries.vbt.signals.clean(exits)[0],
+            pd.DataFrame(
+                np.array([
+                    [False, False, False],
+                    [True, False, False],
+                    [False, False, False],
+                    [False, True, False],
+                    [False, False, False]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            entries.vbt.signals.clean(exits)[1],
+            pd.DataFrame(
+                np.array([
+                    [False, False, False],
+                    [False, False, False],
+                    [False, False, False],
+                    [False, False, False],
+                    [True, False, False]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            entries.vbt.signals.clean(exits, entry_first=False)[0],
+            pd.DataFrame(
+                np.array([
+                    [False, False, False],
+                    [True, False, False],
+                    [False, False, False],
+                    [False, True, False],
+                    [False, False, False]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            entries.vbt.signals.clean(exits, entry_first=False)[1],
+            pd.DataFrame(
+                np.array([
+                    [False, True, False],
+                    [False, False, False],
+                    [False, False, False],
+                    [False, False, False],
+                    [True, False, False]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            pd.DataFrame.vbt.signals.clean(entries, exits)[0],
+            pd.DataFrame(
+                np.array([
+                    [False, False, False],
+                    [True, False, False],
+                    [False, False, False],
+                    [False, True, False],
+                    [False, False, False]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        pd.testing.assert_frame_equal(
+            pd.DataFrame.vbt.signals.clean(entries, exits)[1],
+            pd.DataFrame(
+                np.array([
+                    [False, False, False],
+                    [False, False, False],
+                    [False, False, False],
+                    [False, False, False],
+                    [True, False, False]
+                ]),
+                index=sig.index,
+                columns=sig.columns
+            )
+        )
+        with pytest.raises(Exception) as e_info:
+            _ = pd.Series.vbt.signals.clean(entries, entries, entries)
+
     def test_generate_random(self):
         pd.testing.assert_series_equal(
             pd.Series.vbt.signals.generate_random(
@@ -802,23 +924,23 @@ class TestAccessors:
             pd.Series(np.array([False, False, False, True, False, False]))
         )
 
-    def test_generate_adv_stop_exits(self):
+    def test_generate_ohlc_stop_exits(self):
         pd.testing.assert_frame_equal(
             sig.vbt.signals.generate_stop_exits(ts, -0.1),
-            sig.vbt.signals.generate_adv_stop_exits(ts, sl_stop=0.1)
+            sig.vbt.signals.generate_ohlc_stop_exits(ts, sl_stop=0.1)
         )
         pd.testing.assert_frame_equal(
             sig.vbt.signals.generate_stop_exits(ts, -0.1, trailing=True),
-            sig.vbt.signals.generate_adv_stop_exits(ts, ts_stop=0.1)
+            sig.vbt.signals.generate_ohlc_stop_exits(ts, ts_stop=0.1)
         )
         pd.testing.assert_frame_equal(
             sig.vbt.signals.generate_stop_exits(ts, 0.1),
-            sig.vbt.signals.generate_adv_stop_exits(ts, tp_stop=0.1)
+            sig.vbt.signals.generate_ohlc_stop_exits(ts, tp_stop=0.1)
         )
 
-        def _test_adv_stop_exits(**kwargs):
+        def _test_ohlc_stop_exits(**kwargs):
             out_dict = {'hit_price': np.nan, 'stop_type': -1}
-            result = sig.vbt.signals.generate_adv_stop_exits(
+            result = sig.vbt.signals.generate_ohlc_stop_exits(
                 price['open'], price['high'], price['low'], price['close'],
                 out_dict=out_dict, **kwargs
             )
@@ -828,7 +950,7 @@ class TestAccessors:
                 ex = result
             return result, out_dict['hit_price'], out_dict['stop_type']
 
-        ex, hit_price, stop_type = _test_adv_stop_exits()
+        ex, hit_price, stop_type = _test_ohlc_stop_exits()
         pd.testing.assert_frame_equal(
             ex,
             pd.DataFrame(np.array([
@@ -859,7 +981,7 @@ class TestAccessors:
                 [-1, -1, -1]
             ]), index=sig.index, columns=sig.columns)
         )
-        ex, hit_price, stop_type = _test_adv_stop_exits(sl_stop=0.1)
+        ex, hit_price, stop_type = _test_ohlc_stop_exits(sl_stop=0.1)
         pd.testing.assert_frame_equal(
             ex,
             pd.DataFrame(np.array([
@@ -890,7 +1012,7 @@ class TestAccessors:
                 [0, -1, -1]
             ]), index=sig.index, columns=sig.columns)
         )
-        ex, hit_price, stop_type = _test_adv_stop_exits(ts_stop=0.1)
+        ex, hit_price, stop_type = _test_ohlc_stop_exits(ts_stop=0.1)
         pd.testing.assert_frame_equal(
             ex,
             pd.DataFrame(np.array([
@@ -921,7 +1043,7 @@ class TestAccessors:
                 [1, -1, -1]
             ]), index=sig.index, columns=sig.columns)
         )
-        ex, hit_price, stop_type = _test_adv_stop_exits(tp_stop=0.1)
+        ex, hit_price, stop_type = _test_ohlc_stop_exits(tp_stop=0.1)
         pd.testing.assert_frame_equal(
             ex,
             pd.DataFrame(np.array([
@@ -952,7 +1074,7 @@ class TestAccessors:
                 [-1, -1, -1]
             ]), index=sig.index, columns=sig.columns)
         )
-        ex, hit_price, stop_type = _test_adv_stop_exits(sl_stop=0.1, ts_stop=0.1, tp_stop=0.1)
+        ex, hit_price, stop_type = _test_ohlc_stop_exits(sl_stop=0.1, ts_stop=0.1, tp_stop=0.1)
         pd.testing.assert_frame_equal(
             ex,
             pd.DataFrame(np.array([
@@ -983,7 +1105,7 @@ class TestAccessors:
                 [0, -1, -1]
             ]), index=sig.index, columns=sig.columns)
         )
-        ex, hit_price, stop_type = _test_adv_stop_exits(
+        ex, hit_price, stop_type = _test_ohlc_stop_exits(
             sl_stop=[0., 0.1, 0.2], ts_stop=[0., 0.1, 0.2], tp_stop=[0., 0.1, 0.2])
         pd.testing.assert_frame_equal(
             ex,
@@ -1015,7 +1137,7 @@ class TestAccessors:
                 [-1, -1, 0]
             ]), index=sig.index, columns=sig.columns)
         )
-        ex, hit_price, stop_type = _test_adv_stop_exits(sl_stop=0.1, ts_stop=0.1, tp_stop=0.1, exit_wait=0)
+        ex, hit_price, stop_type = _test_ohlc_stop_exits(sl_stop=0.1, ts_stop=0.1, tp_stop=0.1, exit_wait=0)
         pd.testing.assert_frame_equal(
             ex,
             pd.DataFrame(np.array([
@@ -1046,7 +1168,7 @@ class TestAccessors:
                 [0, 0, -1]
             ]), index=sig.index, columns=sig.columns)
         )
-        (en, ex), hit_price, stop_type = _test_adv_stop_exits(sl_stop=0.1, ts_stop=0.1, tp_stop=0.1, iteratively=True)
+        (en, ex), hit_price, stop_type = _test_ohlc_stop_exits(sl_stop=0.1, ts_stop=0.1, tp_stop=0.1, iteratively=True)
         pd.testing.assert_frame_equal(
             en,
             pd.DataFrame(np.array([
@@ -1103,7 +1225,7 @@ class TestAccessors:
             [True, False, False],
             [False, True, False],
             [True, False, True]
-        ], index=index, columns=columns)
+        ], index=sig.index, columns=sig.columns)
 
         assert sig['a'].vbt.signals.map_reduce_between(
             map_func_nb=distance_map_nb,
@@ -1114,7 +1236,7 @@ class TestAccessors:
                 map_func_nb=distance_map_nb,
                 reduce_func_nb=mean_reduce_nb
             ),
-            pd.Series([3., 3., np.nan], index=sig.columns)
+            pd.Series([3., 3., np.nan], index=sig.columns).rename('map_reduce_between')
         )
         assert sig['a'].vbt.signals.map_reduce_between(
             other=other_sig['b'],
@@ -1127,7 +1249,7 @@ class TestAccessors:
                 map_func_nb=distance_map_nb,
                 reduce_func_nb=mean_reduce_nb
             ),
-            pd.Series([1.5, 2., 2.], index=sig.columns)
+            pd.Series([1.5, 2., 2.], index=sig.columns).rename('map_reduce_between')
         )
 
     def test_map_reduce_partitions(self):
@@ -1148,21 +1270,21 @@ class TestAccessors:
                 map_func_nb=distance_map_nb,
                 reduce_func_nb=mean_reduce_nb
             ),
-            pd.Series([1.5, 1.5, 2.], index=sig.columns)
+            pd.Series([1.5, 1.5, 2.], index=sig.columns).rename('map_reduce_partitions')
         )
 
     def test_num_signals(self):
         assert sig['a'].vbt.signals.num_signals() == 2
         pd.testing.assert_series_equal(
             sig.vbt.signals.num_signals(),
-            pd.Series([2, 2, 1], index=sig.columns)
+            pd.Series([2, 2, 1], index=sig.columns).rename('num_signals')
         )
 
     def test_avg_distance(self):
         assert sig['a'].vbt.signals.avg_distance() == 3.
         pd.testing.assert_series_equal(
             sig.vbt.signals.avg_distance(),
-            pd.Series([3., 3., np.nan], index=sig.columns)
+            pd.Series([3., 3., np.nan], index=sig.columns).rename('avg_distance')
         )
         other_sig = pd.DataFrame([
             [False, False, False],
@@ -1170,11 +1292,11 @@ class TestAccessors:
             [True, False, False],
             [False, True, False],
             [True, False, True]
-        ], index=index, columns=columns)
+        ], index=sig.index, columns=sig.columns)
         assert sig['a'].vbt.signals.avg_distance(to=other_sig['a']) == 1.5
         pd.testing.assert_series_equal(
             sig.vbt.signals.avg_distance(to=other_sig),
-            pd.Series([1.5, 2., 2.], index=sig.columns)
+            pd.Series([1.5, 2., 2.], index=sig.columns).rename('avg_distance')
         )
 
     def test_rank(self):
@@ -1362,9 +1484,9 @@ class TestAccessors:
     @pytest.mark.parametrize(
         "test_func,test_func_pd",
         [
-            (lambda x, *args, **kwargs: x.AND(*args, **kwargs), lambda x, y: x & y),
-            (lambda x, *args, **kwargs: x.OR(*args, **kwargs), lambda x, y: x | y),
-            (lambda x, *args, **kwargs: x.XOR(*args, **kwargs), lambda x, y: x ^ y)
+            (lambda x, *args, **kwargs: x.AND(args, **kwargs), lambda x, y: x & y),
+            (lambda x, *args, **kwargs: x.OR(args, **kwargs), lambda x, y: x | y),
+            (lambda x, *args, **kwargs: x.XOR(args, **kwargs), lambda x, y: x ^ y)
         ],
     )
     def test_logical_funcs(self, test_func, test_func_pd):
@@ -1799,9 +1921,9 @@ class TestFactory:
         )
 
 
-# ############# basic.py ############# #
+# ############# generators.py ############# #
 
-class TestBasic:
+class TestGenerators:
     def test_RAND(self):
         rand = vbt.RAND.run(n=1, input_shape=(6,), seed=seed)
         pd.testing.assert_series_equal(
@@ -1850,10 +1972,10 @@ class TestBasic:
                 [False, False, False, True],
                 [False, False, False, False]
             ]), columns=pd.MultiIndex.from_tuples([
-                ('mix_0', 0),
-                ('mix_0', 1),
-                ('mix_1', 0),
-                ('mix_1', 1)
+                (1, 0),
+                (2, 1),
+                (3, 0),
+                (4, 1)
             ], names=['rand_n', None])
             )
         )
@@ -1869,10 +1991,10 @@ class TestBasic:
                 [False, False, True, False],
                 [False, True, False, True]
             ]), columns=pd.MultiIndex.from_tuples([
-                ('mix_0', 0),
-                ('mix_0', 1),
-                ('mix_1', 0),
-                ('mix_1', 1)
+                (1, 0),
+                (2, 1),
+                (3, 0),
+                (4, 1)
             ], names=['rand_n', None])
             )
         )
@@ -1893,11 +2015,11 @@ class TestBasic:
             input_shape=(5,), seed=seed)
         pd.testing.assert_series_equal(
             rprob.entries,
-            pd.Series(np.array([True, False, True, False, True]), name=('mix_0', 'mix_0'))
+            pd.Series(np.array([True, False, True, False, True]), name=('array_0', 'array_0'))
         )
         pd.testing.assert_series_equal(
             rprob.exits,
-            pd.Series(np.array([False, True, False, True, False]), name=('mix_0', 'mix_0'))
+            pd.Series(np.array([False, True, False, True, False]), name=('array_0', 'array_0'))
         )
         rprob = vbt.RPROB.run(entry_prob=[0.5, 1.], exit_prob=[1., 0.5], input_shape=(5,), seed=seed)
         pd.testing.assert_frame_equal(
@@ -2023,9 +2145,9 @@ class TestBasic:
                 [False, False, True],
                 [True, False, False]
             ]), index=sig.index, columns=pd.MultiIndex.from_tuples([
-                ('mix_0', 'a'),
-                ('mix_0', 'b'),
-                ('mix_0', 'c')
+                ('array_0', 'a'),
+                ('array_0', 'b'),
+                ('array_0', 'c')
             ], names=['stex_stop', None])
             )
         )
@@ -2106,13 +2228,13 @@ class TestBasic:
             )
         )
 
-    def test_ADVSTEX(self):
-        advstex = vbt.ADVSTEX.run(
+    def test_OHLCSTEX(self):
+        ohlcstex = vbt.OHLCSTEX.run(
             sig, price['open'], price['high'], price['low'], price['close'],
             sl_stop=0.1
         )
         pd.testing.assert_frame_equal(
-            advstex.exits,
+            ohlcstex.exits,
             pd.DataFrame(np.array([
                 [False, False, False],
                 [False, False, False],
@@ -2123,11 +2245,11 @@ class TestBasic:
                 (0.1, 'a'),
                 (0.1, 'b'),
                 (0.1, 'c')
-            ], names=['advstex_sl_stop', None])
+            ], names=['ohlcstex_sl_stop', None])
             )
         )
         pd.testing.assert_frame_equal(
-            advstex.hit_price,
+            ohlcstex.hit_price,
             pd.DataFrame(np.array([
                 [np.nan, np.nan, np.nan],
                 [np.nan, np.nan, np.nan],
@@ -2138,11 +2260,11 @@ class TestBasic:
                 (0.1, 'a'),
                 (0.1, 'b'),
                 (0.1, 'c')
-            ], names=['advstex_sl_stop', None])
+            ], names=['ohlcstex_sl_stop', None])
             )
         )
         pd.testing.assert_frame_equal(
-            advstex.stop_type,
+            ohlcstex.stop_type,
             pd.DataFrame(np.array([
                 [-1, -1, -1],
                 [-1, -1, -1],
@@ -2153,15 +2275,15 @@ class TestBasic:
                 (0.1, 'a'),
                 (0.1, 'b'),
                 (0.1, 'c')
-            ], names=['advstex_sl_stop', None])
+            ], names=['ohlcstex_sl_stop', None])
             )
         )
-        advstex = vbt.ADVSTEX.run(
+        ohlcstex = vbt.OHLCSTEX.run(
             sig, price['open'], price['high'], price['low'], price['close'],
             sl_stop=[0.1, 0., 0.], ts_stop=[0., 0.1, 0.], tp_stop=[0., 0., 0.1]
         )
         pd.testing.assert_frame_equal(
-            advstex.exits,
+            ohlcstex.exits,
             pd.DataFrame(np.array([
                 [False, False, False, False, False, False, False, False, False],
                 [False, False, False, False, False, False, True, False, False],
@@ -2178,11 +2300,11 @@ class TestBasic:
                 (0., 0., 0.1, 'a'),
                 (0., 0., 0.1, 'b'),
                 (0., 0., 0.1, 'c')
-            ], names=['advstex_sl_stop', 'advstex_ts_stop', 'advstex_tp_stop', None])
+            ], names=['ohlcstex_sl_stop', 'ohlcstex_ts_stop', 'ohlcstex_tp_stop', None])
             )
         )
         pd.testing.assert_frame_equal(
-            advstex.hit_price,
+            ohlcstex.hit_price,
             pd.DataFrame(np.array([
                 [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan],
                 [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, 11., np.nan, np.nan],
@@ -2199,11 +2321,11 @@ class TestBasic:
                 (0., 0., 0.1, 'a'),
                 (0., 0., 0.1, 'b'),
                 (0., 0., 0.1, 'c')
-            ], names=['advstex_sl_stop', 'advstex_ts_stop', 'advstex_tp_stop', None])
+            ], names=['ohlcstex_sl_stop', 'ohlcstex_ts_stop', 'ohlcstex_tp_stop', None])
             )
         )
         pd.testing.assert_frame_equal(
-            advstex.stop_type,
+            ohlcstex.stop_type,
             pd.DataFrame(np.array([
                 [-1, -1, -1, -1, -1, -1, -1, -1, -1],
                 [-1, -1, -1, -1, -1, -1, 2, -1, -1],
@@ -2220,17 +2342,17 @@ class TestBasic:
                 (0., 0., 0.1, 'a'),
                 (0., 0., 0.1, 'b'),
                 (0., 0., 0.1, 'c')
-            ], names=['advstex_sl_stop', 'advstex_ts_stop', 'advstex_tp_stop', None])
+            ], names=['ohlcstex_sl_stop', 'ohlcstex_ts_stop', 'ohlcstex_tp_stop', None])
             )
         )
 
-    def test_IADVSTEX(self):
-        iadvstex = vbt.IADVSTEX.run(
+    def test_IOHLCSTEX(self):
+        iohlcstex = vbt.IOHLCSTEX.run(
             sig, price['open'], price['high'], price['low'], price['close'],
             sl_stop=[0.1, 0., 0.], ts_stop=[0., 0.1, 0.], tp_stop=[0., 0., 0.1]
         )
         pd.testing.assert_frame_equal(
-            iadvstex.exits,
+            iohlcstex.exits,
             pd.DataFrame(np.array([
                 [False, False, False, False, False, False, False, False, False],
                 [False, False, False, False, False, False, True, False, False],
@@ -2247,11 +2369,11 @@ class TestBasic:
                 (0., 0., 0.1, 'a'),
                 (0., 0., 0.1, 'b'),
                 (0., 0., 0.1, 'c')
-            ], names=['iadvstex_sl_stop', 'iadvstex_ts_stop', 'iadvstex_tp_stop', None])
+            ], names=['iohlcstex_sl_stop', 'iohlcstex_ts_stop', 'iohlcstex_tp_stop', None])
             )
         )
         pd.testing.assert_frame_equal(
-            iadvstex.hit_price,
+            iohlcstex.hit_price,
             pd.DataFrame(np.array([
                 [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, np.nan],
                 [np.nan, np.nan, np.nan, np.nan, np.nan, np.nan, 11., np.nan, np.nan],
@@ -2268,11 +2390,11 @@ class TestBasic:
                 (0., 0., 0.1, 'a'),
                 (0., 0., 0.1, 'b'),
                 (0., 0., 0.1, 'c')
-            ], names=['iadvstex_sl_stop', 'iadvstex_ts_stop', 'iadvstex_tp_stop', None])
+            ], names=['iohlcstex_sl_stop', 'iohlcstex_ts_stop', 'iohlcstex_tp_stop', None])
             )
         )
         pd.testing.assert_frame_equal(
-            iadvstex.stop_type,
+            iohlcstex.stop_type,
             pd.DataFrame(np.array([
                 [-1, -1, -1, -1, -1, -1, -1, -1, -1],
                 [-1, -1, -1, -1, -1, -1, 2, -1, -1],
@@ -2289,7 +2411,7 @@ class TestBasic:
                 (0., 0., 0.1, 'a'),
                 (0., 0., 0.1, 'b'),
                 (0., 0., 0.1, 'c')
-            ], names=['iadvstex_sl_stop', 'iadvstex_ts_stop', 'iadvstex_tp_stop', None])
+            ], names=['iohlcstex_sl_stop', 'iohlcstex_ts_stop', 'iohlcstex_tp_stop', None])
             )
         )
 
