@@ -86,7 +86,7 @@ import numpy as np
 import pandas as pd
 import warnings
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils import checks
 from vectorbt.utils.config import Configured, merge_dicts
 from vectorbt.utils.datetime import freq_to_timedelta, DatetimeIndexes
@@ -174,16 +174,17 @@ class ArrayWrapper(Configured, PandasIndexer):
             as a Series of columns rather than a DataFrame. For example, the operation
             `.iloc[:, :2]` should become `.iloc[:2]`. Operations are not allowed if the
             object is already a Series and thus has only one column/group."""
-        from vectorbt import settings
+        from vectorbt._settings import settings
+        array_wrapper_cfg = settings['array_wrapper']
 
         if column_only_select is None:
             column_only_select = self.column_only_select
         if column_only_select is None:
-            column_only_select = settings.array_wrapper['column_only_select']
+            column_only_select = array_wrapper_cfg['column_only_select']
         if group_select is None:
             group_select = self.group_select
         if group_select is None:
-            group_select = settings.array_wrapper['group_select']
+            group_select = array_wrapper_cfg['group_select']
         _self = self.regroup(group_by)
         group_select = group_select and _self.grouper.is_grouped()
         if index is None:
@@ -208,7 +209,7 @@ class ArrayWrapper(Configured, PandasIndexer):
 
         if column_only_select:
             if i_wrapper.ndim == 1:
-                raise IndexingError("Columns only: Attempting to select a column on a Series")
+                raise IndexingError("Columns only: This object already contains one column of data")
             try:
                 col_mapper = pd_indexing_func(i_wrapper.wrap_reduced(np.arange(n_cols), columns=columns))
             except pd.core.indexing.IndexingError as e:
@@ -410,11 +411,12 @@ class ArrayWrapper(Configured, PandasIndexer):
     @property
     def freq(self) -> tp.Optional[pd.Timedelta]:
         """Index frequency."""
-        from vectorbt import settings
+        from vectorbt._settings import settings
+        array_wrapper_cfg = settings['array_wrapper']
 
         freq = self._freq
         if freq is None:
-            freq = settings.array_wrapper['freq']
+            freq = array_wrapper_cfg['freq']
         if freq is not None:
             return freq_to_timedelta(freq)
         if isinstance(self.index, DatetimeIndexes):
@@ -433,7 +435,8 @@ class ArrayWrapper(Configured, PandasIndexer):
     def to_time_units(self, a: tp.MaybeArray[float]) -> tp.Union[pd.Timedelta, tp.Array]:
         """Convert array to time units."""
         if self.freq is None:
-            raise ValueError("Couldn't parse the frequency of index. You must set `freq`.")
+            raise ValueError("Couldn't parse the frequency of index. "
+                             "Pass it as `freq` or define it globally under `settings.array_wrapper`.")
         return a * self.freq
 
     @property
@@ -626,10 +629,16 @@ class Wrapping(Configured, PandasIndexer):
             return self.copy(wrapper=self.wrapper.regroup(group_by, **kwargs))
         return self  # important for keeping cache
 
-    def select_series(self: WrappingT, column: tp.Any = None, group_by: tp.GroupByLike = None, **kwargs) -> WrappingT:
+    def select_one(self: WrappingT, column: tp.Any = None, group_by: tp.GroupByLike = None, **kwargs) -> WrappingT:
         """Select one column/group."""
         _self = self.regroup(group_by, **kwargs)
         if column is not None:
+            if _self.wrapper.grouper.is_grouped():
+                if column not in _self.wrapper.get_columns():
+                    raise KeyError(f"Group '{column}' not found")
+            else:
+                if column not in _self.wrapper.columns:
+                    raise KeyError(f"Column '{column}' not found")
             return _self[column]
         if not _self.wrapper.grouper.is_grouped():
             if _self.wrapper.ndim == 1:
@@ -638,3 +647,22 @@ class Wrapping(Configured, PandasIndexer):
         if _self.wrapper.grouped_ndim == 1:
             return _self
         raise TypeError("Only one group is allowed. Use indexing or column argument.")
+
+    @staticmethod
+    def select_one_from_obj(obj: tp.SeriesFrame, wrapper: ArrayWrapper, column: tp.Any = None) -> tp.MaybeSeries:
+        """Select one column/group from a pandas object."""
+        if column is not None:
+            if wrapper.grouper.is_grouped():
+                if column not in wrapper.get_columns():
+                    raise KeyError(f"Group '{column}' not found")
+            else:
+                if column not in wrapper.columns:
+                    raise KeyError(f"Column '{column}' not found")
+            return obj[column]
+        if not wrapper.grouper.is_grouped():
+            if wrapper.ndim == 1:
+                return obj
+            raise TypeError("Only one column is allowed. Use indexing or column argument.")
+        if wrapper.grouped_ndim == 1:
+            return obj
+        raise TypeError("Only one group is allowed. Use indexing or column argument.")
