@@ -20,13 +20,13 @@ import numpy as np
 import pandas as pd
 import plotly.graph_objects as go
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils.decorators import cached_property, cached_method
 from vectorbt.utils.config import merge_dicts
 from vectorbt.utils.colors import adjust_lightness
 from vectorbt.utils.datetime import DatetimeIndexes
-from vectorbt.utils.enum import to_value_map
-from vectorbt.utils.figure import make_figure
+from vectorbt.utils.enum import enum_to_value_map
+from vectorbt.utils.figure import make_figure, get_domain
 from vectorbt.base.reshape_fns import to_1d, broadcast_to, to_pd_array
 from vectorbt.base.array_wrapper import ArrayWrapper
 from vectorbt.generic import nb
@@ -131,7 +131,7 @@ class Drawdowns(Records):
         out['Start Date'] = records_df['start_idx'].map(lambda x: self.wrapper.index[x])
         out['Valley Date'] = records_df['valley_idx'].map(lambda x: self.wrapper.index[x])
         out['End Date'] = records_df['end_idx'].map(lambda x: self.wrapper.index[x])
-        out['Status'] = records_df['status'].map(to_value_map(DrawdownStatus))
+        out['Status'] = records_df['status'].map(enum_to_value_map(DrawdownStatus))
         return out
 
     @cached_property
@@ -306,7 +306,8 @@ class Drawdowns(Records):
              vtr_shape_kwargs: tp.KwargsLike = None,
              active_shape_kwargs: tp.KwargsLike = None,
              add_trace_kwargs: tp.KwargsLike = None,
-             xref: str = 'x', yref: str = 'y',
+             xref: str = 'x',
+             yref: str = 'y',
              fig: tp.Optional[tp.BaseFigure] = None,
              **layout_kwargs) -> tp.BaseFigure:  # pragma: no cover
         """Plot drawdowns over `Drawdowns.ts`.
@@ -342,9 +343,10 @@ class Drawdowns(Records):
 
         ![](/vectorbt/docs/img/drawdowns_plot.svg)
         """
-        from vectorbt.settings import color_schema, contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
-        self_col = self.select_series(column=column, group_by=False)
+        self_col = self.select_one(column=column, group_by=False)
         if top_n is not None:
             # Drawdowns is negative, thus top_n becomes bottom_n
             self_col = self_col.filter_by_mask(self_col.drawdown.bottom_n_mask(top_n))
@@ -352,7 +354,9 @@ class Drawdowns(Records):
         if ts_trace_kwargs is None:
             ts_trace_kwargs = {}
         ts_trace_kwargs = merge_dicts(dict(
-            line_color=color_schema['blue']
+            line=dict(
+                color=plotting_cfg['color_schema']['blue']
+            )
         ), ts_trace_kwargs)
         if peak_trace_kwargs is None:
             peak_trace_kwargs = {}
@@ -374,12 +378,7 @@ class Drawdowns(Records):
         if fig is None:
             fig = make_figure()
         fig.update_layout(**layout_kwargs)
-        y_domain = [0, 1]
-        yaxis = 'yaxis' + yref[1:]
-        if yaxis in fig.layout:
-            if 'domain' in fig.layout[yaxis]:
-                if fig.layout[yaxis]['domain'] is not None:
-                    y_domain = fig.layout[yaxis]['domain']
+        y_domain = get_domain(yref, fig)
 
         if plot_ts:
             fig = self_col.ts.vbt.plot(trace_kwargs=ts_trace_kwargs, add_trace_kwargs=add_trace_kwargs, fig=fig)
@@ -415,11 +414,11 @@ class Drawdowns(Records):
                     mode='markers',
                     marker=dict(
                         symbol='diamond',
-                        color=contrast_color_schema['blue'],
+                        color=plotting_cfg['contrast_color_schema']['blue'],
                         size=7,
                         line=dict(
                             width=1,
-                            color=adjust_lightness(contrast_color_schema['blue'])
+                            color=adjust_lightness(plotting_cfg['contrast_color_schema']['blue'])
                         )
                     ),
                     name='Peak',
@@ -443,11 +442,11 @@ class Drawdowns(Records):
                     mode='markers',
                     marker=dict(
                         symbol='diamond',
-                        color=contrast_color_schema['red'],
+                        color=plotting_cfg['contrast_color_schema']['red'],
                         size=7,
                         line=dict(
                             width=1,
-                            color=adjust_lightness(contrast_color_schema['red'])
+                            color=adjust_lightness(plotting_cfg['contrast_color_schema']['red'])
                         )
                     ),
                     name='Valley',
@@ -488,11 +487,11 @@ class Drawdowns(Records):
                     mode='markers',
                     marker=dict(
                         symbol='diamond',
-                        color=contrast_color_schema['green'],
+                        color=plotting_cfg['contrast_color_schema']['green'],
                         size=7,
                         line=dict(
                             width=1,
-                            color=adjust_lightness(contrast_color_schema['green'])
+                            color=adjust_lightness(plotting_cfg['contrast_color_schema']['green'])
                         )
                     ),
                     name='Recovery/Peak',
@@ -535,11 +534,11 @@ class Drawdowns(Records):
                     mode='markers',
                     marker=dict(
                         symbol='diamond',
-                        color=contrast_color_schema['orange'],
+                        color=plotting_cfg['contrast_color_schema']['orange'],
                         size=7,
                         line=dict(
                             width=1,
-                            color=adjust_lightness(contrast_color_schema['orange'])
+                            color=adjust_lightness(plotting_cfg['contrast_color_schema']['orange'])
                         )
                     ),
                     name='Active',
