@@ -3,9 +3,9 @@
 Defines enums and other schemas for `vectorbt.generic`."""
 
 import numpy as np
-import json
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
+from vectorbt.utils.docs import to_doc
 
 __all__ = [
     'DrawdownStatus',
@@ -27,8 +27,8 @@ DrawdownStatus = DrawdownStatusT(*range(2))
 
 __pdoc__['DrawdownStatus'] = f"""Drawdown status.
 
-```plaintext
-{json.dumps(dict(zip(DrawdownStatus._fields, DrawdownStatus)), indent=2, default=str)}
+```json
+{to_doc(DrawdownStatus)}
 ```
 """
 
@@ -44,10 +44,7 @@ drawdown_dt = np.dtype([
 
 __pdoc__['drawdown_dt'] = f"""`np.dtype` of drawdown records.
 
-```plaintext
-{json.dumps(dict(zip(
-    dict(drawdown_dt.fields).keys(),
-    list(map(lambda x: str(x[0]), dict(drawdown_dt.fields).values()))
-)), indent=2, default=str)}
+```json
+{to_doc(drawdown_dt)}
 ```
 """
