@@ -6,7 +6,7 @@ import numpy as np
 import pandas as pd
 import math
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils import checks
 from vectorbt.base.index_fns import find_first_occurrence
 from vectorbt.base.reshape_fns import to_any_array
