@@ -59,7 +59,7 @@ Date
 import numpy as np
 import plotly.graph_objects as go
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils.config import merge_dicts
 from vectorbt.utils.figure import make_figure
 from vectorbt.utils.colors import adjust_opacity
@@ -121,9 +121,10 @@ class _MA(MA):
 
         ![](/vectorbt/docs/img/MA.svg)
         """
-        from vectorbt.settings import color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -135,7 +136,9 @@ class _MA(MA):
             ma_trace_kwargs = {}
         close_trace_kwargs = merge_dicts(dict(
             name='Close',
-            line_color=color_schema['blue']
+            line=dict(
+                color=plotting_cfg['color_schema']['blue']
+            )
         ), close_trace_kwargs)
         ma_trace_kwargs = merge_dicts(dict(
             name='MA'
@@ -204,7 +207,7 @@ class _MSTD(MSTD):
 
         ![](/vectorbt/docs/img/MSTD.svg)
         """
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -295,9 +298,10 @@ class _BBANDS(BBANDS):
 
         ![](/vectorbt/docs/img/BBANDS.svg)
         """
-        from vectorbt.settings import color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -313,11 +317,15 @@ class _BBANDS(BBANDS):
             lower_trace_kwargs = {}
         lower_trace_kwargs = merge_dicts(dict(
             name='Lower Band',
-            line_color=adjust_opacity(color_schema['gray'], 0.75),
+            line=dict(
+                color=adjust_opacity(plotting_cfg['color_schema']['gray'], 0.75)
+            ),
         ), lower_trace_kwargs)
         upper_trace_kwargs = merge_dicts(dict(
             name='Upper Band',
-            line_color=adjust_opacity(color_schema['gray'], 0.75),
+            line=dict(
+                color=adjust_opacity(plotting_cfg['color_schema']['gray'], 0.75)
+            ),
             fill='tonexty',
             fillcolor='rgba(128, 128, 128, 0.2)'
         ), upper_trace_kwargs)  # default kwargs
@@ -326,7 +334,7 @@ class _BBANDS(BBANDS):
         ), middle_trace_kwargs)
         close_trace_kwargs = merge_dicts(dict(
             name='Close',
-            line=dict(color=color_schema['blue'])
+            line=dict(color=plotting_cfg['color_schema']['blue'])
         ), close_trace_kwargs)
 
         fig = self_col.lower.vbt.plot(
@@ -408,7 +416,7 @@ class _RSI(RSI):
 
         ![](/vectorbt/docs/img/RSI.svg)
         """
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -511,7 +519,7 @@ class _STOCH(STOCH):
 
         ![](/vectorbt/docs/img/STOCH.svg)
         """
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -623,7 +631,7 @@ class _MACD(MACD):
         ```
 
         ![](/vectorbt/docs/img/MACD.svg)"""
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -735,7 +743,7 @@ class _ATR(ATR):
 
         ![](/vectorbt/docs/img/ATR.svg)
         """
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
@@ -808,7 +816,7 @@ class _OBV(OBV):
 
         ![](/vectorbt/docs/img/OBV.svg)
         """
-        self_col = self.select_series(column=column)
+        self_col = self.select_one(column=column)
 
         if fig is None:
             fig = make_figure()
