@@ -2,9 +2,8 @@
 
 Defines enums and other schemas for `vectorbt.labels`."""
 
-import json
-
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
+from vectorbt.utils.docs import to_doc
 
 __all__ = [
     'TrendMode'
@@ -14,20 +13,20 @@ __pdoc__ = {}
 
 
 class TrendModeT(tp.NamedTuple):
-    Binary: int
-    BinaryCont: int
-    BinaryContSat: int
-    PctChange: int
-    PctChangeNorm: int
+    Binary: int = 0
+    BinaryCont: int = 1
+    BinaryContSat: int = 2
+    PctChange: int = 3
+    PctChangeNorm: int = 4
 
 
-TrendMode = TrendModeT(*range(5))
+TrendMode = TrendModeT()
 """_"""
 
 __pdoc__['TrendMode'] = f"""Trend mode.
 
-```plaintext
-{json.dumps(dict(zip(TrendMode._fields, TrendMode)), indent=2, default=str)}
+```json
+{to_doc(TrendMode)}
 ```
 
 Attributes:
