@@ -12,7 +12,7 @@ The accessors inherit `vectorbt.generic.accessors`.
 import numpy as np
 import plotly.graph_objects as go
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.root_accessors import register_dataframe_accessor
 from vectorbt.utils import checks
 from vectorbt.utils.figure import make_figure, make_subplots
@@ -66,7 +66,9 @@ class OHLCVDFAccessor(GenericDFAccessor):  # pragma: no cover
 
         ![](/vectorbt/docs/img/ohlcv.svg)
         """
-        from vectorbt.settings import ohlcv, color_schema
+        from vectorbt._settings import settings
+        ohlcv_cfg = settings['ohlcv']
+        plotting_cfg = settings['plotting']
 
         if ohlc_kwargs is None:
             ohlc_kwargs = {}
@@ -80,11 +82,11 @@ class OHLCVDFAccessor(GenericDFAccessor):  # pragma: no cover
             ohlc_add_trace_kwargs = merge_dicts(dict(row=1, col=1), ohlc_add_trace_kwargs)
             volume_add_trace_kwargs = merge_dicts(dict(row=2, col=1), volume_add_trace_kwargs)
 
-        column_names = ohlcv['column_names'] if self._column_names is None else self._column_names
-        open = self._obj[column_names['open']]
-        high = self._obj[column_names['high']]
-        low = self._obj[column_names['low']]
-        close = self._obj[column_names['close']]
+        column_names = ohlcv_cfg['column_names'] if self._column_names is None else self._column_names
+        open = self.obj[column_names['open']]
+        high = self.obj[column_names['high']]
+        low = self.obj[column_names['low']]
+        close = self.obj[column_names['close']]
 
         # Set up figure
         if fig is None:
@@ -114,7 +116,7 @@ class OHLCVDFAccessor(GenericDFAccessor):  # pragma: no cover
                 )
         fig.update_layout(**layout_kwargs)
         if plot_type is None:
-            plot_type = ohlcv['plot_type']
+            plot_type = ohlcv_cfg['plot_type']
         if isinstance(plot_type, str):
             if plot_type.lower() == 'ohlc':
                 plot_type = 'OHLC'
@@ -133,19 +135,27 @@ class OHLCVDFAccessor(GenericDFAccessor):  # pragma: no cover
             low=low,
             close=close,
             name=plot_type,
-            increasing_line_color=color_schema['increasing'],
-            decreasing_line_color=color_schema['decreasing']
+            increasing=dict(
+                line=dict(
+                    color=plotting_cfg['color_schema']['increasing']
+                )
+            ),
+            decreasing=dict(
+                line=dict(
+                    color=plotting_cfg['color_schema']['decreasing']
+                )
+            )
         )
         ohlc.update(**ohlc_kwargs)
         fig.add_trace(ohlc, **ohlc_add_trace_kwargs)
 
         if display_volume:
-            volume = self._obj[column_names['volume']]
+            volume = self.obj[column_names['volume']]
 
             marker_colors = np.empty(volume.shape, dtype=object)
-            marker_colors[(close.values - open.values) > 0] = color_schema['increasing']
-            marker_colors[(close.values - open.values) == 0] = color_schema['gray']
-            marker_colors[(close.values - open.values) < 0] = color_schema['decreasing']
+            marker_colors[(close.values - open.values) > 0] = plotting_cfg['color_schema']['increasing']
+            marker_colors[(close.values - open.values) == 0] = plotting_cfg['color_schema']['gray']
+            marker_colors[(close.values - open.values) < 0] = plotting_cfg['color_schema']['decreasing']
             volume_bar = go.Bar(
                 x=self.wrapper.index,
                 y=volume,
