@@ -9,10 +9,10 @@ import numpy as np
 import pandas as pd
 import plotly.graph_objects as go
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils.decorators import cached_property, cached_method
 from vectorbt.utils.colors import adjust_lightness
-from vectorbt.utils.enum import to_value_map
+from vectorbt.utils.enum import enum_to_value_map
 from vectorbt.utils.figure import make_figure
 from vectorbt.utils.config import merge_dicts
 from vectorbt.base.reshape_fns import to_1d, to_2d, broadcast_to
@@ -97,7 +97,7 @@ class Orders(Records):
         out['Size'] = records_df['size']
         out['Price'] = records_df['price']
         out['Fees'] = records_df['fees']
-        out['Side'] = records_df['side'].map(to_value_map(OrderSide))
+        out['Side'] = records_df['side'].map(enum_to_value_map(OrderSide))
         return out
 
     @cached_property
@@ -182,15 +182,18 @@ class Orders(Records):
         ```
 
         ![](/vectorbt/docs/img/orders_plot.svg)"""
-        from vectorbt.settings import color_schema, contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
-        self_col = self.select_series(column=column, group_by=False)
+        self_col = self.select_one(column=column, group_by=False)
 
         if close_trace_kwargs is None:
             close_trace_kwargs = {}
         close_trace_kwargs = merge_dicts(dict(
-            line_color=color_schema['blue'],
-            name='Close' if self_col.wrapper.name is None else self_col.wrapper.name
+            line=dict(
+                color=plotting_cfg['color_schema']['blue']
+            ),
+            name='Close'
         ), close_trace_kwargs)
         if buy_trace_kwargs is None:
             buy_trace_kwargs = {}
@@ -225,11 +228,11 @@ class Orders(Records):
                 mode='markers',
                 marker=dict(
                     symbol='triangle-up',
-                    color=contrast_color_schema['green'],
+                    color=plotting_cfg['contrast_color_schema']['green'],
                     size=8,
                     line=dict(
                         width=1,
-                        color=adjust_lightness(contrast_color_schema['green'])
+                        color=adjust_lightness(plotting_cfg['contrast_color_schema']['green'])
                     )
                 ),
                 name='Buy',
@@ -252,11 +255,11 @@ class Orders(Records):
                 mode='markers',
                 marker=dict(
                     symbol='triangle-down',
-                    color=contrast_color_schema['red'],
+                    color=plotting_cfg['contrast_color_schema']['red'],
                     size=8,
                     line=dict(
                         width=1,
-                        color=adjust_lightness(contrast_color_schema['red'])
+                        color=adjust_lightness(plotting_cfg['contrast_color_schema']['red'])
                     )
                 ),
                 name='Sell',
