@@ -16,13 +16,13 @@ import numpy as np
 import pandas as pd
 import plotly.graph_objects as go
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils.colors import adjust_lightness
 from vectorbt.utils.decorators import cached_property, cached_method
 from vectorbt.utils.config import merge_dicts
 from vectorbt.utils.datetime import DatetimeIndexes
-from vectorbt.utils.enum import to_value_map
-from vectorbt.utils.figure import make_figure
+from vectorbt.utils.enum import enum_to_value_map
+from vectorbt.utils.figure import make_figure, get_domain
 from vectorbt.utils.array import min_rel_rescale, max_rel_rescale
 from vectorbt.base.reshape_fns import to_1d, to_2d, broadcast_to
 from vectorbt.base.array_wrapper import ArrayWrapper
@@ -111,9 +111,9 @@ class Trades(Records):
     ```python-repl
     >>> price = pd.Series([1., 2., 3., 4., 3., 2., 1.])
     >>> orders = pd.Series([1., -0.5, -0.5, 2., -0.5, -0.5, -0.5])
-    >>> portfolio = vbt.Portfolio.from_orders(price, orders)
+    >>> pf = vbt.Portfolio.from_orders(price, orders)
 
-    >>> trades = vbt.Trades.from_orders(portfolio.orders)
+    >>> trades = vbt.Trades.from_orders(pf.orders)
     >>> trades.count()
     6
     >>> trades.pnl.sum()
@@ -214,8 +214,8 @@ class Trades(Records):
         out['Exit Fees'] = records_df['exit_fees']
         out['PnL'] = records_df['pnl']
         out['Return'] = records_df['return']
-        out['Direction'] = records_df['direction'].map(to_value_map(TradeDirection))
-        out['Status'] = records_df['status'].map(to_value_map(TradeStatus))
+        out['Direction'] = records_df['direction'].map(enum_to_value_map(TradeDirection))
+        out['Status'] = records_df['status'].map(enum_to_value_map(TradeStatus))
         if self.trade_type == TradeType.Trade:
             out['Position Id'] = records_df['position_id']
         return out
@@ -409,9 +409,10 @@ class Trades(Records):
             fig (Figure or FigureWidget): Figure to add traces to.
             **layout_kwargs: Keyword arguments for layout.
         """
-        from vectorbt.settings import contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
-        self_col = self.select_series(column=column, group_by=False)
+        self_col = self.select_one(column=column, group_by=False)
 
         if closed_profit_trace_kwargs is None:
             closed_profit_trace_kwargs = {}
@@ -434,22 +435,16 @@ class Trades(Records):
             _layout_kwargs[yaxis] = dict(tickformat='.2%')
             fig.update_layout(**_layout_kwargs)
         fig.update_layout(**layout_kwargs)
-        x_domain = [0, 1]
-        if xaxis in fig.layout:
-            if 'domain' in fig.layout[xaxis]:
-                if fig.layout[xaxis]['domain'] is not None:
-                    x_domain = fig.layout[xaxis]['domain']
+        x_domain = get_domain(xref, fig)
 
         if len(self_col.values) > 0:
             # Extract information
-            _id = self.values['id']
-            _id_str = 'Trade Id' if self.trade_type == TradeType.Trade else 'Position Id'
             _pnl_str = '%{customdata[1]:.6f}' if as_pct else '%{y}'
             _return_str = '%{y}' if as_pct else '%{customdata[1]:.2%}'
-            exit_idx = self.values['exit_idx']
-            pnl = self.values['pnl']
-            returns = self.values['return']
-            status = self.values['status']
+            exit_idx = self_col.values['exit_idx']
+            pnl = self_col.values['pnl']
+            returns = self_col.values['return']
+            status = self_col.values['status']
 
             neutral_mask = pnl == 0
             profit_mask = pnl > 0
@@ -465,6 +460,26 @@ class Trades(Records):
 
             def _plot_scatter(mask: tp.Array1d, name: tp.TraceName, color: tp.Any, kwargs: tp.Kwargs) -> None:
                 if np.any(mask):
+                    if self_col.trade_type == TradeType.Trade:
+                        customdata = np.stack((
+                            self_col.values['id'][mask],
+                            self_col.values['position_id'][mask],
+                            pnl[mask] if as_pct else returns[mask]
+                        ), axis=1)
+                        hovertemplate = "Trade Id: %{customdata[0]}" \
+                                        "<br>Position Id: %{customdata[1]}" \
+                                        "<br>Date: %{x}" \
+                                        f"<br>PnL: {_pnl_str}" \
+                                        f"<br>Return: {_return_str}"
+                    else:
+                        customdata = np.stack((
+                            self_col.values['id'][mask],
+                            pnl[mask] if as_pct else returns[mask]
+                        ), axis=1)
+                        hovertemplate = "Position Id: %{customdata[0]}" \
+                                        "<br>Date: %{x}" \
+                                        f"<br>PnL: {_pnl_str}" \
+                                        f"<br>Return: {_return_str}"
                     scatter = go.Scatter(
                         x=self_col.wrapper.index[exit_idx[mask]],
                         y=returns[mask] if as_pct else pnl[mask],
@@ -480,14 +495,8 @@ class Trades(Records):
                             ),
                         ),
                         name=name,
-                        customdata=np.stack((
-                            _id[mask],
-                            pnl[mask] if as_pct else returns[mask]
-                        ), axis=1),
-                        hovertemplate=_id_str + ": %{customdata[0]}"
-                                                "<br>Date: %{x}"
-                                                f"<br>PnL: {_pnl_str}"
-                                                f"<br>Return: {_return_str}"
+                        customdata=customdata,
+                        hovertemplate=hovertemplate
                     )
                     scatter.update(**kwargs)
                     fig.add_trace(scatter, **add_trace_kwargs)
@@ -496,7 +505,7 @@ class Trades(Records):
             _plot_scatter(
                 closed_profit_mask,
                 'Closed - Profit',
-                contrast_color_schema['green'],
+                plotting_cfg['contrast_color_schema']['green'],
                 closed_profit_trace_kwargs
             )
 
@@ -504,7 +513,7 @@ class Trades(Records):
             _plot_scatter(
                 closed_loss_mask,
                 'Closed - Loss',
-                contrast_color_schema['red'],
+                plotting_cfg['contrast_color_schema']['red'],
                 closed_loss_trace_kwargs
             )
 
@@ -512,7 +521,7 @@ class Trades(Records):
             _plot_scatter(
                 open_mask,
                 'Open',
-                contrast_color_schema['orange'],
+                plotting_cfg['contrast_color_schema']['orange'],
                 open_trace_kwargs
             )
 
@@ -594,15 +603,18 @@ class Trades(Records):
         ```
 
         ![](/vectorbt/docs/img/trades_plot.svg)"""
-        from vectorbt.settings import color_schema, contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
-        self_col = self.select_series(column=column, group_by=False)
+        self_col = self.select_one(column=column, group_by=False)
 
         if close_trace_kwargs is None:
             close_trace_kwargs = {}
         close_trace_kwargs = merge_dicts(dict(
-            line_color=color_schema['blue'],
-            name='Close' if self_col.wrapper.name is None else self_col.wrapper.name
+            line=dict(
+                color=plotting_cfg['color_schema']['blue']
+            ),
+            name='Close'
         ), close_trace_kwargs)
         if entry_trace_kwargs is None:
             entry_trace_kwargs = {}
@@ -642,7 +654,7 @@ class Trades(Records):
             exit_fees = self_col.values['exit_fees']
             pnl = self_col.values['pnl']
             ret = self_col.values['return']
-            direction_value_map = to_value_map(TradeDirection)
+            direction_value_map = enum_to_value_map(TradeDirection)
             direction = self_col.values['direction']
             direction = np.vectorize(lambda x: str(direction_value_map[x]))(direction)
             status = self_col.values['status']
@@ -674,11 +686,11 @@ class Trades(Records):
                     mode='markers',
                     marker=dict(
                         symbol='square',
-                        color=contrast_color_schema['blue'],
+                        color=plotting_cfg['contrast_color_schema']['blue'],
                         size=7,
                         line=dict(
                             width=1,
-                            color=adjust_lightness(contrast_color_schema['blue'])
+                            color=adjust_lightness(plotting_cfg['contrast_color_schema']['blue'])
                         )
                     ),
                     name='Entry',
@@ -743,7 +755,7 @@ class Trades(Records):
             _plot_end_markers(
                 (status == TradeStatus.Closed) & (pnl == 0.),
                 'Exit',
-                contrast_color_schema['gray'],
+                plotting_cfg['contrast_color_schema']['gray'],
                 exit_trace_kwargs
             )
 
@@ -751,7 +763,7 @@ class Trades(Records):
             _plot_end_markers(
                 (status == TradeStatus.Closed) & (pnl > 0.),
                 'Exit - Profit',
-                contrast_color_schema['green'],
+                plotting_cfg['contrast_color_schema']['green'],
                 exit_profit_trace_kwargs
             )
 
@@ -759,7 +771,7 @@ class Trades(Records):
             _plot_end_markers(
                 (status == TradeStatus.Closed) & (pnl < 0.),
                 'Exit - Loss',
-                contrast_color_schema['red'],
+                plotting_cfg['contrast_color_schema']['red'],
                 exit_loss_trace_kwargs
             )
 
@@ -767,7 +779,7 @@ class Trades(Records):
             _plot_end_markers(
                 status == TradeStatus.Open,
                 'Active',
-                contrast_color_schema['orange'],
+                plotting_cfg['contrast_color_schema']['orange'],
                 active_trace_kwargs
             )
 
