@@ -4,7 +4,7 @@ import pandas as pd
 from inspect import getmembers, isfunction
 import plotly.express as px
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.root_accessors import register_dataframe_accessor, register_series_accessor
 from vectorbt.utils import checks
 from vectorbt.utils.figure import make_figure
@@ -20,24 +20,25 @@ def add_px_methods(cls: tp.Type[tp.T]) -> tp.Type[tp.T]:
         if checks.method_accepts_argument(px_func, 'data_frame') or px_func_name == 'imshow':
             def plot_func(self, *args, _px_func_name: str = px_func_name,
                           _px_func: tp.Callable = px_func, **kwargs) -> tp.BaseFigure:
-                from vectorbt.settings import layout
+                from vectorbt._settings import settings
+                layout_cfg = settings['plotting']['layout']
 
                 layout_kwargs = dict(
-                    template=kwargs.pop('template', layout['template']),
-                    width=kwargs.pop('width', layout['width']),
-                    height=kwargs.pop('height', layout['height'])
+                    template=kwargs.pop('template', layout_cfg['template']),
+                    width=kwargs.pop('width', layout_cfg['width']),
+                    height=kwargs.pop('height', layout_cfg['height'])
                 )
                 # Fix category_orders
                 if 'color' in kwargs:
                     if isinstance(kwargs['color'], str):
-                        if isinstance(self._obj, pd.DataFrame):
-                            if kwargs['color'] in self._obj.columns:
+                        if isinstance(self.obj, pd.DataFrame):
+                            if kwargs['color'] in self.obj.columns:
                                 category_orders = dict()
-                                category_orders[kwargs['color']] = sorted(self._obj[kwargs['color']].unique())
+                                category_orders[kwargs['color']] = sorted(self.obj[kwargs['color']].unique())
                                 kwargs = merge_dicts(dict(category_orders=category_orders), kwargs)
 
                 # Fix Series name
-                obj = self._obj.copy(deep=False)
+                obj = self.obj.copy(deep=False)
                 if isinstance(obj, pd.Series):
                     if obj.name is not None:
                         obj = obj.rename(str(obj.name))
