@@ -25,7 +25,7 @@ array([0., 0.09090909, 0.18181818, 0.09090909, 0.])
 import numpy as np
 from numba import njit
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.generic import nb as generic_nb
 
 
