@@ -58,7 +58,7 @@ Run for the examples below:
 import numpy as np
 import pandas as pd
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.root_accessors import register_dataframe_accessor, register_series_accessor
 from vectorbt.utils import checks
 from vectorbt.utils.decorators import class_or_instancemethod
@@ -292,13 +292,13 @@ class SignalsAccessor(GenericAccessor):
         If one array passed, see `SignalsAccessor.first`.
         If two arrays passed, entries and exits, see `vectorbt.signals.nb.clean_enex_nb`."""
         if not isinstance(self_or_cls, type):
-            args = (self_or_cls._obj, *args)
+            args = (self_or_cls.obj, *args)
         if len(args) == 1:
             obj = args[0]
             if not isinstance(obj, (pd.Series, pd.DataFrame)):
                 wrapper = ArrayWrapper.from_shape(np.asarray(obj).shape)
-                obj = wrapper.wrap(obj, **merge_dicts({}, wrap_kwargs))
-            return obj.vbt.signals.first()
+                obj = wrapper.wrap(obj)
+            return obj.vbt.signals.first(wrap_kwargs=wrap_kwargs)
         elif len(args) == 2:
             if broadcast_kwargs is None:
                 broadcast_kwargs = {}
@@ -495,7 +495,7 @@ class SignalsAccessor(GenericAccessor):
         ```
         """
         if prob is not None:
-            obj, prob = reshape_fns.broadcast(self._obj, prob, keep_raw=[False, True])
+            obj, prob = reshape_fns.broadcast(self.obj, prob, keep_raw=[False, True])
             exits = nb.generate_rand_ex_by_prob_nb(obj.vbt.to_2d_array(), prob, wait, obj.ndim == 2, seed=seed)
             return obj.vbt.wrapper.wrap(exits, **merge_dicts({}, wrap_kwargs))
         exits = nb.generate_rand_ex_nb(self.to_2d_array(), wait, seed=seed)
@@ -548,7 +548,7 @@ class SignalsAccessor(GenericAccessor):
         """
         if broadcast_kwargs is None:
             broadcast_kwargs = {}
-        entries = self._obj
+        entries = self.obj
 
         keep_raw = (False, True, True, True)
         broadcast_kwargs = merge_dicts(dict(require_kwargs=dict(requirements='W')), broadcast_kwargs)
@@ -617,9 +617,6 @@ class SignalsAccessor(GenericAccessor):
         >>> exits = sig.vbt.signals.generate_ohlc_stop_exits(
         ...     price['open'], price['high'], price['low'], price['close'],
         ...     out_dict=out_dict, sl_stop=0.2, ts_stop=0.2, tp_stop=0.2)
-        >>> out_dict['hit_price'][~exits] = np.nan
-        >>> out_dict['stop_type'][~exits] = -1
-
         >>> exits
                         a      b      c
         2020-01-01  False  False  False
@@ -636,8 +633,7 @@ class SignalsAccessor(GenericAccessor):
         2020-01-04   NaN   NaN  NaN
         2020-01-05   NaN   NaN  9.6
 
-        >>> out_dict['stop_type'].applymap(
-        ...     lambda x: StopType._fields[x] if x in StopType else '')
+        >>> out_dict['stop_type'].vbt.map_enum(StopType)
                              a           b         c
         2020-01-01
         2020-01-02  TakeProfit  TakeProfit
@@ -648,7 +644,7 @@ class SignalsAccessor(GenericAccessor):
         """
         if broadcast_kwargs is None:
             broadcast_kwargs = {}
-        entries = self._obj
+        entries = self.obj
         if high is None:
             high = open
         if low is None:
@@ -656,9 +652,12 @@ class SignalsAccessor(GenericAccessor):
         if close is None:
             close = open
         if out_dict is None:
+            out_dict_passed = False
             out_dict = {}
-        hit_price_out = out_dict.get('hit_price', None)
-        stop_type_out = out_dict.get('stop_type', None)
+        else:
+            out_dict_passed = True
+        hit_price_out = out_dict.get('hit_price', np.nan if out_dict_passed else None)
+        stop_type_out = out_dict.get('stop_type', -1 if out_dict_passed else None)
         out_args = ()
         if hit_price_out is not None:
             out_args += (hit_price_out,)
@@ -674,15 +673,13 @@ class SignalsAccessor(GenericAccessor):
             hit_price_out = np.empty_like(entries, dtype=np.float_)
         else:
             hit_price_out = out_args[0]
-            if checks.is_pandas(hit_price_out):
-                hit_price_out = hit_price_out.vbt.to_2d_array()
             out_args = out_args[1:]
         if stop_type_out is None:
             stop_type_out = np.empty_like(entries, dtype=np.int_)
         else:
             stop_type_out = out_args[0]
-            if checks.is_pandas(stop_type_out):
-                stop_type_out = stop_type_out.vbt.to_2d_array()
+        hit_price_out = reshape_fns.to_2d(hit_price_out, raw=True)
+        stop_type_out = reshape_fns.to_2d(stop_type_out, raw=True)
 
         # Perform generation
         if iteratively:
@@ -759,7 +756,7 @@ class SignalsAccessor(GenericAccessor):
             return self.wrapper.wrap_reduced(result, **wrap_kwargs)
         else:
             # Two input arrays
-            obj, other = reshape_fns.broadcast(self._obj, other, **broadcast_kwargs)
+            obj, other = reshape_fns.broadcast(self.obj, other, **broadcast_kwargs)
             checks.assert_dtype(other, np.bool_)
             result = nb.map_reduce_between_two_nb(
                 obj.vbt.to_2d_array(),
@@ -871,10 +868,10 @@ class SignalsAccessor(GenericAccessor):
         if broadcast_kwargs is None:
             broadcast_kwargs = {}
         if reset_by is not None:
-            obj, reset_by = reshape_fns.broadcast(self._obj, reset_by, **broadcast_kwargs)
+            obj, reset_by = reshape_fns.broadcast(self.obj, reset_by, **broadcast_kwargs)
             reset_by = reset_by.vbt.to_2d_array()
         else:
-            obj = self._obj
+            obj = self.obj
         ranked = nb.rank_nb(
             obj.vbt.to_2d_array(),
             reset_by=reset_by,
@@ -918,10 +915,10 @@ class SignalsAccessor(GenericAccessor):
         if broadcast_kwargs is None:
             broadcast_kwargs = {}
         if reset_by is not None:
-            obj, reset_by = reshape_fns.broadcast(self._obj, reset_by, **broadcast_kwargs)
+            obj, reset_by = reshape_fns.broadcast(self.obj, reset_by, **broadcast_kwargs)
             reset_by = reset_by.vbt.to_2d_array()
         else:
-            obj = self._obj
+            obj = self.obj
         ranked = nb.rank_partitions_nb(
             obj.vbt.to_2d_array(),
             reset_by=reset_by,
@@ -999,7 +996,7 @@ class SignalsAccessor(GenericAccessor):
             tickvals=[0, 1],
             ticktext=['false', 'true']
         )
-        return self._obj.vbt.lineplot(**merge_dicts(default_layout, kwargs))
+        return self.obj.vbt.lineplot(**merge_dicts(default_layout, kwargs))
 
 
 @register_series_accessor('signals')
@@ -1034,22 +1031,23 @@ class SignalsSRAccessor(SignalsAccessor, GenericSRAccessor):
 
         ![](/vectorbt/docs/img/signals_plot_as_markers.svg)
         """
-        from vectorbt.settings import contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
         if y is None:
-            y = pd.Series.vbt.empty_like(self._obj, 1)
+            y = pd.Series.vbt.empty_like(self.obj, 1)
         else:
             y = reshape_fns.to_pd_array(y)
 
-        return y[self._obj].vbt.scatterplot(**merge_dicts(dict(
+        return y[self.obj].vbt.scatterplot(**merge_dicts(dict(
             trace_kwargs=dict(
                 marker=dict(
                     symbol='circle',
-                    color=contrast_color_schema['blue'],
+                    color=plotting_cfg['contrast_color_schema']['blue'],
                     size=7,
                     line=dict(
                         width=1,
-                        color=adjust_lightness(contrast_color_schema['blue'])
+                        color=adjust_lightness(plotting_cfg['contrast_color_schema']['blue'])
                     )
                 )
             )
@@ -1060,17 +1058,18 @@ class SignalsSRAccessor(SignalsAccessor, GenericSRAccessor):
         """Plot signals as entry markers.
 
         See `SignalsSRAccessor.plot_as_markers`."""
-        from vectorbt.settings import contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
         return self.plot_as_markers(y=y, **merge_dicts(dict(
             trace_kwargs=dict(
                 marker=dict(
                     symbol='triangle-up',
-                    color=contrast_color_schema['green'],
+                    color=plotting_cfg['contrast_color_schema']['green'],
                     size=8,
                     line=dict(
                         width=1,
-                        color=adjust_lightness(contrast_color_schema['green'])
+                        color=adjust_lightness(plotting_cfg['contrast_color_schema']['green'])
                     )
                 ),
                 name='Entry'
@@ -1082,17 +1081,18 @@ class SignalsSRAccessor(SignalsAccessor, GenericSRAccessor):
         """Plot signals as exit markers.
 
         See `SignalsSRAccessor.plot_as_markers`."""
-        from vectorbt.settings import contrast_color_schema
+        from vectorbt._settings import settings
+        plotting_cfg = settings['plotting']
 
         return self.plot_as_markers(y=y, **merge_dicts(dict(
             trace_kwargs=dict(
                 marker=dict(
                     symbol='triangle-down',
-                    color=contrast_color_schema['red'],
+                    color=plotting_cfg['contrast_color_schema']['red'],
                     size=8,
                     line=dict(
                         width=1,
-                        color=adjust_lightness(contrast_color_schema['red'])
+                        color=adjust_lightness(plotting_cfg['contrast_color_schema']['red'])
                     )
                 ),
                 name='Exit'
