@@ -2,9 +2,8 @@
 
 Defines enums and other schemas for `vectorbt.signals`."""
 
-import json
-
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
+from vectorbt.utils.docs import to_doc
 
 __all__ = [
     'StopType'
@@ -14,17 +13,17 @@ __pdoc__ = {}
 
 
 class StopTypeT(tp.NamedTuple):
-    StopLoss: int
-    TrailStop: int
-    TakeProfit: int
+    StopLoss: int = 0
+    TrailStop: int = 1
+    TakeProfit: int = 2
 
 
-StopType = StopTypeT(*range(3))
+StopType = StopTypeT()
 """_"""
 
 __pdoc__['StopType'] = f"""Stop type.
 
-```plaintext
-{json.dumps(dict(zip(StopType._fields, StopType)), indent=2, default=str)}
+```json
+{to_doc(StopType)}
 ```
 """
