@@ -10,7 +10,7 @@ import numpy as np
 from numba import njit
 import inspect
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils import checks
 from vectorbt.utils.config import merge_dicts
 from vectorbt.utils.params import to_typed_list
