@@ -1,7 +1,8 @@
 """Modules with utilities that are used throughout vectorbt."""
 
 from vectorbt.utils.config import atomic_dict, merge_dicts, Config, Configured, AtomicConfig
-from vectorbt.utils.decorators import cached_property, cached_method
+from vectorbt.utils.template import Sub, Rep, RepEval, RepFunc, deep_substitute
+from vectorbt.utils.decorators import CacheCondition, cached_property, cached_method
 from vectorbt.utils.figure import Figure, FigureWidget, make_figure, make_subplots
 from vectorbt.utils.random import set_seed
 from vectorbt.utils.image import save_animation
@@ -13,6 +14,12 @@ __all__ = [
     'Config',
     'Configured',
     'AtomicConfig',
+    'Sub',
+    'Rep',
+    'RepEval',
+    'RepFunc',
+    'deep_substitute',
+    'CacheCondition',
     'cached_property',
     'cached_method',
     'Figure',
