@@ -4,7 +4,7 @@ from numba.typed import List
 import itertools
 from collections.abc import Callable
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils import checks
 
 
