@@ -7,7 +7,7 @@ import asyncio
 import logging
 import inspect
 
-from vectorbt import typing as tp
+from vectorbt import _typing as tp
 from vectorbt.utils.datetime import tzaware_to_naive_time
 from vectorbt.utils import checks
 
